function imo = gaboaspectplot(imo,xx,yy,AspX,AspY,SF,Ori,Pha,Radius,Cur,palsize)
%****************** make a gabor ***********************************
% imo = gaboaspect(imo,xx,yy,AspX,AspY,SF,Ori,Pha,Radius,palsize)
%*****
%  imo - 2-D image to write pixels
%  xx - x-center in image
%  yy - y-center in image
%  AspX - aspect of dim perp ori, set 1 for round gabor, larger to elongate
%  AspY - aspect of dim par ori, set 1 for round gabor, larger to elongate
%  SF - spatial frequencies, pixels in a cycle, figure 8 pixels per degree
%  Ori - 1 of 8 orientations
%  Pha - phase of gabor, 0 to 2*pi
%  Radius - total radius of stim
%  palsize - discretization of grey level (palette size)

Nx = size(imo,1);
Ny = size(imo,2);
DropOff = 3;  % how many gaussian deviations of gabor to drop off in item radius
FrameNum = 1;   % total movie frames to make
Cycle = SF;
  
smallfieldsize = (Radius*2)+2;  % put stimulus inside a box of this size      
frame = 1;  
[bars]=zeros(smallfieldsize,smallfieldsize,FrameNum);   % array to hold movie values
  
%Orientation = floor(mod(Ori,8)*22.5-90);   % this uses vertical as Ori=1, Horizontal ori=5
Orientation = Ori;
AspectX = AspX;
AspectY = AspY;
     
%************* this code below draws the gabor then *****************  
xcomp = cos( Orientation*(pi/180.));
ycomp = sin( Orientation*(pi/180.));
if (abs(-90-Orientation)<0.01)
   xcomp = 0;
   ycomp = 1;
end
if (abs(0.0-Orientation)<0.01)
   xcomp = 1;
   ycomp = 0;
end

for i=1:smallfieldsize
  %******************************************
  xreal = ((i-(smallfieldsize/2)))-0.0;  
  xii = floor(xreal+xx);
  if  ( (xii<1) | (xii>Nx) )
      continue;
  end
  %*****************************************
  for j=1:smallfieldsize
        %***********************************
        yreal = ((j-(smallfieldsize/2)))-0.0;
        yii = floor(yreal+yy);
        if  ( (yii<1) | (yii>Ny) )
            continue;
        end       
        
        %************* use rotation matrix to rotate coordinates *****
        xrota = ((xreal*xcomp)+(yreal*ycomp));
        yrota = (-(xreal*ycomp)+(yreal*xcomp));
        %*********** parabolic transform
        % Cur = 0.25 modest curve, 4 = strong curve
        xrot = xrota + (Radius*Cur)*((yrota/Radius)^2);
        yrot = yrota;
        %*******************************
        
        if (sqrt(xreal^2+yreal^2)<Radius)  % draw a gabor kernel
        
              gauss = exp( -AspectX*(xrot^2)/(2*(Radius/DropOff)^2) );
              gauss = gauss * exp( -AspectY*(yrot^2)/(2*(Radius/DropOff)^2) );
              coso = cos( (xrot*2*pi/Cycle));
              val = gauss*coso;
              if (Pha == 1)
                  if (val<-0.05)
                      val = -1;
                  end
                  if (val>0.05)
                      val = 1;
                  end
              end
              
              pval = 1+round((val*0.5*(palsize-1)));
              if (abs(val)<(1/palsize))
                imo(xii,yii) = imo(xii,yii) + 0;    % allow transparency to background if zero
              else
                imo(xii,yii) = imo(xii,yii) + pval;
              end
              
        end % if sqrt within radius
    end % for j
 end %for i
  
 
return;